@@ -19,19 +19,19 @@
 #' @seealso [bm_list()]
 #' @export
 as_bm_list <- function(x, ...) {
-    UseMethod("as_bm_list")
+	UseMethod("as_bm_list")
 }
 
 #' @rdname as_bm_list
 #' @export
 as_bm_list.default <- function(x, ...) {
-    as_bm_list.list(as.list(x, ...))
+	as_bm_list.list(as.list(x, ...))
 }
 
 #' @rdname as_bm_list
 #' @export
 as_bm_list.bm_list <- function(x, ...) {
-    x
+	x
 }
 
 #' @rdname as_bm_list
@@ -39,24 +39,38 @@ as_bm_list.bm_list <- function(x, ...) {
 #'            as [as_bm_bitmap()] or [as_bm_pixmap()].
 #' @export
 as_bm_list.list <- function(x, ..., FUN = identity) {
-    x <- lapply(x, FUN = FUN, ...)
-    all_bm <- all(vapply(x, is_supported_bitmap, FUN.VALUE = logical(1L)))
-    stopifnot(`Some elements were not supported bitmap objects` = all_bm)
-    class(x) <- c("bm_list", class(x))
-    x
+	x <- lapply(x, FUN = FUN, ...)
+	all_bm <- all(vapply(x, is_supported_bitmap, FUN.VALUE = logical(1L)))
+	stopifnot(`Some elements were not supported bitmap objects` = all_bm)
+	class(x) <- c("bm_list", class(x))
+	x
 }
 
 #' @rdname as_bm_list
 #' @export
 as_bm_list.character <- function(x, ..., font = bm_font()) {
-    x <- paste(x, collapse = "")
-    if (nchar(x) == 0) return(bm_list())
-    ucp <- str2ucp(x)
-    bml <- as_bm_list(font[ucp])
-    stopifnot(!any(sapply(bml, is.null)))
-    bml
+	x <- paste(x, collapse = "")
+	if (nchar(x) == 0) {
+		return(bm_list())
+	}
+	ucp <- str2ucp(x)
+	bml <- as_bm_list(font[ucp])
+	stopifnot(!any(sapply(bml, is.null)))
+	bml
 }
 
+#' Test if the object is a bitmap object supported by the methods in this package
+#'
+#' `is_supported_bitmap()` returns `TRUE` for `bm_bitmap`, `bm_pixmap`, `magick-image`, `nativeRaster`, and `raster` objects (or subclasses)
+#' and `FALSE` for all other objects.
+#' @param x An object
+#' @return `TRUE` or `FALSE`
+#' @examples
+#' space_matrix <- matrix(0L, nrow = 16L, ncol = 16L)
+#' space_glyph <- bm_bitmap(space_matrix)
+#' is_supported_bitmap(space_glyph)
+#' @seealso [is_bm_bitmap()], [is_bm_pixmap()], [grDevices::is.raster()]
+#' @export
 is_supported_bitmap <- function(x) {
-    inherits(x, c("bm_bitmap", "bm_pixmap", "magick-image", "nativeRaster", "raster"))
+	inherits(x, c("bm_bitmap", "bm_pixmap", "magick-image", "nativeRaster", "raster"))
 }
