@@ -24,69 +24,67 @@
 #' print(bm_padding_lengths(corn))
 #' @export
 bm_padding_lengths <- function(x, value) {
-    UseMethod("bm_padding_lengths")
+	UseMethod("bm_padding_lengths")
 }
 
 #' @rdname bm_padding_lengths
 #' @export
 bm_padding_lengths.bm_bitmap <- function(x, value = 0L) {
-    bm_padding_lengths_bitmap(x, value = as.integer(value))
+	bm_padding_lengths_bitmap(x, value = as.integer(value))
 }
 
 #' @rdname bm_padding_lengths
 #' @export
 bm_padding_lengths.bm_list <- function(x, ...) {
-    lapply(x, bm_padding_lengths, ...)
+	lapply(x, bm_padding_lengths, ...)
 }
 
 #' @rdname bm_padding_lengths
 #' @export
 bm_padding_lengths.bm_pixmap <- function(x, value = col2hex("transparent")) {
-    bm_padding_lengths_bitmap(x, value = col2hex(value))
+	bm_padding_lengths_bitmap(x, value = col2hex(value))
 }
 
 #' @rdname bm_padding_lengths
 #' @export
 `bm_padding_lengths.magick-image` <- function(x, value = "transparent") {
-    stopifnot(requireNamespace("magick", quietly = TRUE))
-    value <- col2hex(value)
-    bm_padding_lengths_bitmap(`as_bm_pixmap.magick-image`(x), 
-                              value = value)
+	stopifnot(requireNamespace("magick", quietly = TRUE))
+	value <- col2hex(value)
+	bm_padding_lengths_bitmap(`as_bm_pixmap.magick-image`(x), value = value)
 }
 
 #' @rdname bm_padding_lengths
 #' @export
 bm_padding_lengths.nativeRaster <- function(x, value = col2int("transparent")) {
-    value <- int2col(as_native(value))
-    bm_padding_lengths_bitmap(as_bm_pixmap.nativeRaster(x), 
-                              value = value)
+	value <- int2col(as_native(value))
+	bm_padding_lengths_bitmap(as_bm_pixmap.nativeRaster(x), value = value)
 }
 
 #' @rdname bm_padding_lengths
 #' @export
 bm_padding_lengths.raster <- function(x, value = "transparent") {
-    bm_padding_lengths_bitmap(as_bm_pixmap.raster(x), 
-                              value = col2hex(value))
+	bm_padding_lengths_bitmap(as_bm_pixmap.raster(x), value = col2hex(value))
 }
 
-bm_padding_lengths_bitmap <- function(bm_bitmap, value = 0L) { # nolint
-    height <- nrow(bm_bitmap)
-    width <- ncol(bm_bitmap)
+bm_padding_lengths_bitmap <- function(bm_bitmap, value = 0L) {
+	# nolint
+	height <- nrow(bm_bitmap)
+	width <- ncol(bm_bitmap)
 
-    row_padding <- apply(bm_bitmap, 1, function(x) all(x == value))
-    if (all(row_padding) || height == 0L || width == 0L) {
-        top <- height %/% 2L
-        bottom <- height - top
-        right <- width %/% 2L
-        left <- width - right
-    } else {
-        col_non_padding <- which(!apply(bm_bitmap, 2, function(x) all(x == value)))
-        row_non_padding <- which(!row_padding)
+	row_padding <- apply(bm_bitmap, 1, function(x) all(x == value))
+	if (all(row_padding) || height == 0L || width == 0L) {
+		top <- height %/% 2L
+		bottom <- height - top
+		right <- width %/% 2L
+		left <- width - right
+	} else {
+		col_non_padding <- which(!apply(bm_bitmap, 2, function(x) all(x == value)))
+		row_non_padding <- which(!row_padding)
 
-        left <- col_non_padding[1L] - 1L
-        right <- width - col_non_padding[length(col_non_padding)]
-        bottom <- row_non_padding[1L] - 1L
-        top <- height - row_non_padding[length(row_non_padding)]
-    }
-    return(c(top = top, right = right, bottom = bottom, left = left))
+		left <- col_non_padding[1L] - 1L
+		right <- width - col_non_padding[length(col_non_padding)]
+		bottom <- row_non_padding[1L] - 1L
+		top <- height - row_non_padding[length(row_non_padding)]
+	}
+	return(c(top = top, right = right, bottom = bottom, left = left))
 }
