@@ -16,19 +16,18 @@
 #' col2hex("#00000000")
 #' @export
 col2hex <- function(x) {
-    if (requireNamespace("colorfast", quietly = TRUE)) {
-        rgba <- colorfast::col_to_rgb(x)
-    } else {
-        rgba <- grDevices::col2rgb(x, alpha = TRUE)
-    }
-    which_transparent <- which(rgba[4, ] == 0L)
-    if (length(which_transparent)) {
-        rgba[1, which_transparent] <- 255L
-        rgba[2, which_transparent] <- 255L
-        rgba[3, which_transparent] <- 255L
-    }
-    grDevices::rgb(rgba[1, ], rgba[2, ], rgba[3, ], rgba[4, ],
-                   maxColorValue = 255)
+	if (requireNamespace("colorfast", quietly = TRUE)) {
+		rgba <- colorfast::col_to_rgb(x)
+	} else {
+		rgba <- grDevices::col2rgb(x, alpha = TRUE)
+	}
+	which_transparent <- which(rgba[4, ] == 0L)
+	if (length(which_transparent)) {
+		rgba[1, which_transparent] <- 255L
+		rgba[2, which_transparent] <- 255L
+		rgba[3, which_transparent] <- 255L
+	}
+	grDevices::rgb(rgba[1, ], rgba[2, ], rgba[3, ], rgba[4, ], maxColorValue = 255)
 }
 
 #' Color to (native) integer conversions
@@ -47,29 +46,36 @@ col2hex <- function(x) {
 #' }
 #' @export
 col2int <- function(x) {
-    stopifnot(requireNamespace("colorfast", quietly = TRUE) ||
-              requireNamespace("farver", quietly = TRUE))
-    if (requireNamespace("colorfast", quietly = TRUE)) {
-        colorfast::col_to_int(col2hex(x))
-    } else {
-        farver::encode_native(col2hex(x))
-    }
+	if (requireNamespace("colorfast", quietly = TRUE)) {
+		colorfast::col_to_int(col2hex(x))
+	} else if (requireNamespace("farver", quietly = TRUE)) {
+		farver::encode_native(col2hex(x))
+	} else {
+		stop("Requires either the `{colorfast}` or `{farver}` packages")
+	}
 }
 
 as_native <- function(x) {
-    if (is.numeric(x)) {
-        as.integer(x)
-    } else {
-        col2int(col2hex(x))
-    }
+	if (is.numeric(x)) {
+		as.integer(x)
+	} else {
+		col2int(col2hex(x))
+	}
 }
 
 #' @rdname col2int
-#' @importFrom utils packageVersion
 #' @export
 int2col <- function(x) {
-    stopifnot(requireNamespace("farver", quietly = TRUE))
-    col2hex(farver::decode_native(x))
+	if (
+		requireNamespace("colorfast", quietly = TRUE) &&
+			exists("int_to_col", getNamespace("colorfast"))
+	) {
+		col2hex(colorfast::int_to_col(x))
+	} else if (requireNamespace("farver", quietly = TRUE)) {
+		col2hex(farver::decode_native(x))
+	} else {
+		stop("Requires either the `{colorfast}` or `{farver}` packages")
+	}
 }
 
 `%||%` <- function(x, y) if (is.null(x)) y else x # nolint
@@ -77,59 +83,59 @@ int2col <- function(x) {
 # Technically we convert to Luma value using BT. 601 as recommended by
 # https://poynton.ca/notes/colour_and_gamma/ColorFAQ.html
 rgb2grey <- function(red, green, blue) {
-    # 0.2126 * red + 0.7152 * green + 0.0722 * blue # BT. 709
-    0.299 * red + 0.587 * green + 0.114 * blue # BT. 601
+	# 0.2126 * red + 0.7152 * green + 0.0722 * blue # BT. 709
+	0.299 * red + 0.587 * green + 0.114 * blue # BT. 601
 }
 
 hex2grey <- function(col) {
-    rgb2grey(hex2red(col), hex2green(col), hex2blue(col))
+	rgb2grey(hex2red(col), hex2green(col), hex2blue(col))
 }
 
 rgba2brightness <- function(red, green, blue, alpha = 1) {
-    alpha * rgb2grey(red, green, blue)
+	alpha * rgb2grey(red, green, blue)
 }
 
 hex2brightness <- function(col, alpha = NULL) {
-    alpha <- alpha %||% hex2alpha(col)
-    alpha * hex2grey(col)
+	alpha <- alpha %||% hex2alpha(col)
+	alpha * hex2grey(col)
 }
 
 rgba2darkness <- function(red, green, blue, alpha = 1) {
-    alpha * (1 - rgb2grey(red, green, blue))
+	alpha * (1 - rgb2grey(red, green, blue))
 }
 
 hex2darkness <- function(col, alpha = NULL) {
-    alpha <- alpha %||% hex2alpha(col)
-    alpha * (1 - hex2grey(col))
+	alpha <- alpha %||% hex2alpha(col)
+	alpha * (1 - hex2grey(col))
 }
 
 # From quick-and-dirty StackOverflow suggestion
-mean_col <- function (x) {
-    cols <- as.character(x)
-    m <- grDevices::col2rgb(cols) / 255
-    v <- apply(m, 1, quadratic_mean)
-    grDevices::rgb(v[1L], v[2L], v[3L])
+mean_col <- function(x) {
+	cols <- as.character(x)
+	m <- grDevices::col2rgb(cols) / 255
+	v <- apply(m, 1, quadratic_mean)
+	grDevices::rgb(v[1L], v[2L], v[3L])
 }
-quadratic_mean <- function (x) sqrt(mean(x^2))
+quadratic_mean <- function(x) sqrt(mean(x^2))
 
 # From 0 to 1
 hex2red <- function(col) {
-    as.double(as.hexmode(substr(col, 2, 3))) / 255
+	as.double(as.hexmode(substr(col, 2, 3))) / 255
 }
 # From 0 to 1
 hex2green <- function(col) {
-    as.double(as.hexmode(substr(col, 4, 5))) / 255
+	as.double(as.hexmode(substr(col, 4, 5))) / 255
 }
 # From 0 to 1
 hex2blue <- function(col) {
-    as.double(as.hexmode(substr(col, 6, 7))) / 255
+	as.double(as.hexmode(substr(col, 6, 7))) / 255
 }
 # From 0 to 1
 hex2alpha <- function(col) {
-    as.double(as.hexmode(substr(col, 8, 9))) / 255
+	as.double(as.hexmode(substr(col, 8, 9))) / 255
 }
 
 # From 0 to 255
 hex2alpha255 <- function(col) {
-    as.integer(as.hexmode(substr(col, 8, 9)))
+	as.integer(as.hexmode(substr(col, 8, 9)))
 }
